pub struct FileOrFiles {
pub partition_index: u64,
pub start: u64,
pub length: u64,
pub path_type: Option<PathType>,
pub file_format: Option<FileFormat>,
}Expand description
Many files consist of indivisible chunks (e.g. parquet row groups or CSV rows). If a slice partially selects an indivisible chunk then the consumer should employ some rule to decide which slice to include the chunk in (e.g. include it in the slice that contains the midpoint of the chunk)
Fields
partition_index: u64The index of the partition this item belongs to
start: u64The start position in byte to read from this item
length: u64The length in byte to read from this item
path_type: Option<PathType>URIs specify the location of files that are locally-accessible to the consumer. “Locally-accessible” means the consumer can access the files directly, which may include blob storage (e.g., S3, GCS, Azure Blob Storage) in addition to local filesystem paths. The protocol portion of the URI determines the storage type.
file_format: Option<FileFormat>The format of the files along with options for reading those files.